summaryrefslogtreecommitdiff
path: root/libdiskfs/file-get-children.c
diff options
context:
space:
mode:
Diffstat (limited to 'libdiskfs/file-get-children.c')
-rw-r--r--libdiskfs/file-get-children.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/libdiskfs/file-get-children.c b/libdiskfs/file-get-children.c
index 4581e4e0..98d5d60e 100644
--- a/libdiskfs/file-get-children.c
+++ b/libdiskfs/file-get-children.c
@@ -24,9 +24,9 @@
#include <argz.h>
-/* Return any active translators bound to nodes of the receiving
- filesystem. CHILDREN is an argz vector containing file names
- relative to the root of the receiving translator. */
+/* Return any active translators bound to nodes below CRED. CHILDREN
+ is an argz vector containing file names relative to the path of
+ CRED. */
error_t
diskfs_S_file_get_children (struct protid *cred,
char **children,
@@ -79,7 +79,8 @@ diskfs_S_file_get_children (struct protid *cred,
char *c = NULL;
size_t c_len = 0;
- err = fshelp_get_active_translators (&c, &c_len, check_access);
+ err = fshelp_get_active_translators (&c, &c_len, check_access,
+ cred->po->path);
if (err)
goto errout;